@@ -2,10 +2,9 @@ package Geo::Coder::Google::V2;
 
 use strict;
 use warnings;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 use Carp;
-use Encode;
 use JSON;
 use HTTP::Request;
 use LWP::UserAgent;
@@ -44,10 +43,6 @@ sub geocode {
     my $location = $param{location}
         or Carp::croak("Usage: geocode(location => \$location)");
 
-    if (Encode::is_utf8($location)) {
-        $location = Encode::encode_utf8($location);
-    }
-
     my $uri = URI->new("http://$self->{host}/maps/geo");
     my %query_parameters = (q => $location, output => 'json');
     $query_parameters{hl} = $self->{language} if defined $self->{language};
